@@ -16,7 +16,7 @@
 
 # You should have received a copy of the GNU General Public License
 # along with ontv; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 import os.path
 from gettext import gettext as _
@@ -28,6 +28,7 @@ import GUI
 from Configuration import Configuration
 from XMLTVFile import XMLTVFile
 from Reminders import Reminders
+from KeyBinder import KeyBinder
 from ProgramWindow import ProgramWindow
 from PreferencesDialog import PreferencesDialog
 from SearchDialog import SearchDialog
@@ -56,6 +57,9 @@ class OnTVApplet(object):
         if os.path.exists(self.reminders.file):
             self.reminders = self.reminders.load()
 
+        self.kb = KeyBinder(self.config)
+        self.kb.connect("activated", self.__kb_activated)
+
         self.pw = ProgramWindow(self.xmltvfile, self.applet,
                                 self.get_docking_data)
         self.sd = SearchDialog(self.xmltvfile, self.reminders)
@@ -94,9 +98,9 @@ class OnTVApplet(object):
 
     def __button_press(self, button, event):
         if event.type == gtk.gdk.BUTTON_PRESS and event.button == 1:
-            self.press_button()
+            self.__press_button()
 
-    def press_button(self):
+    def __press_button(self):
         if not self.pw.props.visible:
             self.applet.set_state(gtk.STATE_SELECTED)
             self.pw.position_window()
@@ -121,6 +125,12 @@ class OnTVApplet(object):
     def __xmltvfile_loaded(self, xmltvfile, listings):
         self.set_tooltip(None)
 
+    def __kb_activated(self, kb, name, time):
+        if name == "show-window-hotkey":
+            self.__press_button()
+        elif name == "show-search-program-hotkey":
+            self.sd.present(time)
+
     def get_docking_data(self, middle, w=0, h=0):
         self.applet.realize()
         (x, y) = self.applet.window.get_origin()
