@@ -16,7 +16,7 @@
 
 # You should have received a copy of the GNU General Public License
 # along with ontv; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 from gettext import gettext as _
 
@@ -27,7 +27,6 @@ import pango
 
 import Configuration
 import GUI
-from KeyBinder import KeyBinder
 from Reminders import Reminder
 
 class PreferencesDialog:
@@ -36,9 +35,9 @@ class PreferencesDialog:
         self.config = ontvapplet.config
         self.xmltvfile = ontvapplet.xmltvfile
         self.reminders = ontvapplet.reminders
+        self.kb = ontvapplet.kb
         self.pw = ontvapplet.pw
         self.sd = ontvapplet.sd
-        self.kb = KeyBinder(self.config)
 
         self.xmltvfile.connect("loaded", self.__xmltvfile_loaded)
 
@@ -139,12 +138,12 @@ class PreferencesDialog:
 
         self.channels_treeview_menu = gtk.Menu()
         self.add_logo_imi = gtk.ImageMenuItem(gtk.STOCK_ADD)
-        self.add_logo_imi.child.set_markup_with_mnemonic("_Add logo")
+        self.add_logo_imi.child.set_markup_with_mnemonic(_("_Add logo"))
         self.add_logo_imi.show()
         self.channels_treeview_menu.append(self.add_logo_imi)
 
         self.remove_logo_imi = gtk.ImageMenuItem(gtk.STOCK_REMOVE)
-        self.remove_logo_imi.child.set_markup_with_mnemonic("_Remove logo")
+        self.remove_logo_imi.child.set_markup_with_mnemonic(_("_Remove logo"))
         self.remove_logo_imi.show()
         self.channels_treeview_menu.append(self.remove_logo_imi)
 
@@ -227,7 +226,8 @@ class PreferencesDialog:
         cell.props.text = reminder.notify_time
 
     def __connect_widgets(self):
-        self.closebutton.connect("clicked", self.__closebutton_clicked)
+        self.dialog.connect("close", self.__close_dialog)
+        self.closebutton.connect("clicked", self.__close_dialog)
 
         # General tab
         self.xmltv_file_entry.connect("activate",
@@ -268,7 +268,7 @@ class PreferencesDialog:
         self.update_reminder_button.connect("clicked", self.__update_reminder_button_clicked)
         self.remove_reminder_button.connect("clicked", self.__remove_reminder_button_clicked)
 
-    def __closebutton_clicked(self, button):
+    def __close_dialog(self, widget):
         self.dialog.hide()
 
     def __xmltv_file_entry_activate(self, entry):
@@ -546,12 +546,8 @@ class PreferencesDialog:
             self.show_window_hotkey_entry.set_sensitive(enable)
             self.show_search_program_hotkey_entry.set_sensitive(enable)
             if enable:
-                self.kb.show_window_hotkey = self.config.show_window_hotkey
-                self.kb.bind(self.config.show_window_hotkey,
-                             self.ontvapplet.press_button)
-                self.kb.show_search_program_hotkey = self.config.show_search_program_hotkey
-                self.kb.bind(self.config.show_search_program_hotkey,
-                             self.sd.show)
+                self.kb.props.show_window_hotkey = self.config.show_window_hotkey
+                self.kb.props.show_search_program_hotkey = self.config.show_search_program_hotkey
             else:
                 self.kb.unbind(self.config.show_window_hotkey)
                 self.kb.unbind(self.config.show_search_program_hotkey)
@@ -565,10 +561,9 @@ class PreferencesDialog:
             value = entry.value.to_string()
             self.show_window_hotkey_entry.set_text(value)
             if self.config.enable_hotkeys:
-                if self.kb.show_window_hotkey:
-                    self.kb.unbind(self.kb.show_window_hotkey)
-                self.kb.show_window_hotkey = value
-                self.kb.bind(value, self.ontvapplet.press_button)
+                if self.kb.props.show_window_hotkey != "":
+                    self.kb.unbind(self.kb.props.show_window_hotkey)
+                self.kb.props.show_window_hotkey = value
         else:
             self.show_window_hotkey_entry.set_text("!type error!")
 
@@ -579,10 +574,9 @@ class PreferencesDialog:
             value = entry.value.to_string()
             self.show_search_program_hotkey_entry.set_text(value)
             if self.config.enable_hotkeys:
-                if self.kb.show_search_program_hotkey:
-                    self.kb.unbind(self.kb.show_search_program_hotkey)
-                self.kb.show_search_program_hotkey = value
-                self.kb.bind(value, self.sd.show)
+                if self.kb.props.show_search_program_hotkey != "":
+                    self.kb.unbind(self.kb.props.show_search_program_hotkey)
+                self.kb.props.show_search_program_hotkey = value
         else:
             self.show_search_program_hotkey_entry.set_text("!type error!")
 
